==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/mn.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Хадгалах төхөөрөмж нь түр хугацаанд ашиглах боломжгүй байна",
    "Storage invalid" : "Хадгалах төхөөрөмж буруу байна",
    "Unknown error" : "Үл мэдэгдэх алдаа",
    "All files" : "Бүх файлууд",
    "Recent" : "Сүүлийн үеийн",
    "Favorites" : "Онцолсон",
    "File could not be found" : "Файл олдсонгүй",
    "Move or copy" : "Зөөх эсвэл хуулах",
    "Download" : "Татаж авах ",
    "Delete" : "Устгах",
    "Home" : "Нүүр хуудас",
    "Close" : "Хаах",
    "Could not create folder \"{dir}\"" : "\"{dir}\" ийм хавтас үүсгэж болохгүй байна",
    "Upload cancelled." : "Байршуулалт цуцлагдсан. ",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} нь 0kb хэмжээтэй эсвэл ижил нэр бүхий хавтас байгаа тул байршуулах боломжгүй",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "хангалттай зай үлдээгүй байна, та {size1} хэмжээтэй файл оруулж байна гэхдээ зөвхөн {size2} ийн хэмжээний сул зай үлдсэн байна",
    "Target folder \"{dir}\" does not exist any more" : "{dir} гэх байршуулах хавтас олдсонгүй",
    "Not enough free space" : "Сул зай хүрэлцэхгүй байна",
    "Uploading …" : "Байршуулж байна...",
    "Uploading that item is not supported" : "Энэ төрлийн файл байршуулах боломжгүй",
    "Target folder does not exist any more" : "Байршуулах хавтас олдсонгүй",
    "Error when assembling chunks, status code {status}" : "Бүрдэл хэсгүүдийг нэгтгэхэд алдаа гарлаа. Төлвийн код {status}",
    "Actions" : "Үйл ажиллагаа",
    "Rename" : "Нэр өөрчлөх",
    "Copy" : "Хуулах",
    "Target folder" : "Заагч хавтас",
    "Disconnect storage" : "Хадгалах төхөөрөмж салгах",
    "Unshare" : "Түгээлтийг зогсоох",
    "Files" : "Файлууд",
    "Details" : "Дэлгэрэнгүй",
    "Select" : "Сонгох",
    "Pending" : "Хүлээгдэж байгаа",
    "Unable to determine date" : "Огноог тодорхойлох боломжгүй",
    "This operation is forbidden" : "Энэ үйлдэл хориотой",
    "This directory is unavailable, please check the logs or contact the administrator" : "Энэ хавтас байхгүй байна, үйлдлийн лог шалгах эсвэл админ хэрэглэгчтэй холбогдоно уу.",
    "Could not move \"{file}\", target exists" : "\"{file}\" -г зөөж чадсангүй, алдаа: target exists ",
    "Could not move \"{file}\"" : "Файлыг зөөж чадсангүй: \"{file}\"",
    "Could not copy \"{file}\", target exists" : "\"{file}\"-г зөөж чадсангүй, файлын нэр давхцаж байна",
    "Could not copy \"{file}\"" : "\"{file}\"-г зөөж чадсангүй",
    "Copied {origin} inside {destination}" : "Хуулбар хийгдэж {destination} дотор {origin} байршлаа",
    "{newName} already exists" : "{newName} нэр давцаж байна",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" файлын нэрийг солих боломжгүй, энэ файл устгагдсан байна",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{dir}\" хавтаст \"{targetName}\" гэх нэрийг ашигласан байна. Өөр нэр сонгоно уу.",
    "Could not rename \"{fileName}\"" : "Файлын нэрийг сольж чадсангүй: \"{fileName}\"",
    "Could not create file \"{file}\"" : "\"{file}\" файлыг үүсгэж чадсангүй",
    "Could not create file \"{file}\" because it already exists" : "Ийм нэртэй файл байгаа учир \"{file}\"-г үүсгэж чадахгүй",
    "Could not create folder \"{dir}\" because it already exists" : " \"{dir}\" хавтасыг үүсгэх боломжгүй, нэр нь давцаж байна",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" файлыг устгахад алдаа гарлаа.",
    "No search results in other folders for {tag}{filter}{endtag}" : "{tag}{filter}{endtag} хайлтад тохирох үр дүн бусад хавтасаас олсонгүй",
    "Name" : "Нэр",
    "Size" : "Хэмжээ",
    "Modified" : "Өөрчлөгдсөн",
    "_%n folder_::_%n folders_" : ["хавтас","хавтсууд"],
    "_%n file_::_%n files_" : ["файл","файлууд"],
    "{dirs} and {files}" : "{dirs} болон {files}",
    "_including %n hidden_::_including %n hidden_" : ["нуугдсан %n хамруулан","нуугдсан %n хамруулан"],
    "You don’t have permission to upload or create files here" : "Та энэ байршилд файл үүсгэх эсвэл байршуулах эрхгүй байна.",
    "_Uploading %n file_::_Uploading %n files_" : ["Файлыг байршуулж байна","%n файлыг байршуулж байна"],
    "New" : "Шинэ",
    "{used} of {quota} used" : "{quota} оноосноос {used} хэрэглэсэн",
    "{used} used" : "{user} хэрэглэсэн",
    "\"{name}\" is an invalid file name." : "\"{name}\" нь хүчин төгөлдөр бус файлын нэр",
    "File name cannot be empty." : "Файлын нэр хоосон байж болохгүй.",
    "\"/\" is not allowed inside a file name." : "файлын нэр \"/\" агуулж болохгүй",
    "View in folder" : "Хавтасыг нээх",
    "Copied!" : "Хуулсан!",
    "Path" : "Зам",
    "Favorite" : "Дуртай",
    "New folder" : "Шинэ хавтас",
    "Upload file" : "Файл байршуулах",
    "An error occurred while trying to update the tags" : "Tag шинэчлэхэд алдаа гарлаа",
    "Added to favorites" : "Дуртай файлаар сонгов",
    "You added {file} to your favorites" : "{file} дуртай файлаар сонгов",
    "You removed {file} from your favorites" : "Та дуртай файлын жагсаалтаас  {file}-г хасав",
    "File changes" : "Файлын өөрчлөлтүүд",
    "Created by {user}" : "{user} үүсгэсэн",
    "Changed by {user}" : "{user} өөрчилсөн",
    "Deleted by {user}" : "{user} устгасан",
    "Restored by {user}" : "{user} сэргээсэн",
    "Renamed by {user}" : "{user} нэр солисон",
    "Moved by {user}" : "{user} зөөсөн",
    "\"remote user\"" : "алсын хэрэглэгч",
    "You created {file}" : "{file} файлыг та үүсгэв",
    "{user} created {file}" : "{user} {file}-г үүсгэв",
    "{file} was created in a public folder" : "{file} нийтийн хавтсанд үүсгэгдсэн",
    "You changed {file}" : "Та {file} файлыг өөрчлөв",
    "{user} changed {file}" : "{user} хэрэглэгч {file}-г өөрчлөв",
    "You deleted {file}" : "Та {file} файлыг устгав",
    "{user} deleted {file}" : "{user} хэрэглэгч {file} файлыг устгав",
    "You restored {file}" : "Та {file} файлыг сэргээв",
    "{user} restored {file}" : "{user} хэрэглэгч {file} файлыг сэргээв",
    "You renamed {oldfile} to {newfile}" : "Та {oldfile} файлын нэрйиг {newfile} болгож өөрчлөв",
    "{user} renamed {oldfile} to {newfile}" : "{user} хэрэглэгч {oldfile} файлын нэрийг {newfile} болгож өөрчлөв",
    "You moved {oldfile} to {newfile}" : "Та {oldfile} файлыг {newfile} болгож зөөв",
    "{user} moved {oldfile} to {newfile}" : "{user} хэрэглэгч {oldfile} файлыг {newfile} болгож зөөв",
    "File handling" : "файлтай харьцах",
    "Maximum upload size" : "хамгийн их байршуулах хэмжээ",
    "max. possible: " : "боломжтой хамгийн их хэмжээ",
    "Save" : "хадгалах",
    "Settings" : "Тохиргоо",
    "Show hidden files" : "Нууцлагдсан файлыг харах",
    "No files in here" : "энэд файл байхгүй байна",
    "No entries found in this folder" : "энэ хавтсан олдсон ч ямарч мэдээлэл олдохгүй байна",
    "Select all" : "бүгдийг сонгох",
    "Upload too large" : "маш том байршуулалт",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Таны байршуулах гэж оролдсон файлууд нь энэ сервер дээр файл байршуулах дээд хэмжээнээс хэтэрч.",
    "Tags" : "Тэгүүд",
    "Deleted files" : "Устгасан файлууд",
    "Text file" : "текст файл",
    "New text file.txt" : "шинэ текст file.txt",
    "Shared with others" : "Бусдад түгээсэн",
    "Shared by link" : "Холбоосоор түгээсэн"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/mn.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Хадгалах төхөөрөмж нь түр хугацаанд ашиглах боломжгүй байна",
    "Storage invalid" : "Хадгалах төхөөрөмж буруу байна",
    "Unknown error" : "Үл мэдэгдэх алдаа",
    "All files" : "Бүх файлууд",
    "Recent" : "Сүүлийн үеийн",
    "Favorites" : "Онцолсон",
    "File could not be found" : "Файл олдсонгүй",
    "Move or copy" : "Зөөх эсвэл хуулах",
    "Download" : "Татаж авах ",
    "Delete" : "Устгах",
    "Home" : "Нүүр хуудас",
    "Close" : "Хаах",
    "Could not create folder \"{dir}\"" : "\"{dir}\" ийм хавтас үүсгэж болохгүй байна",
    "Upload cancelled." : "Байршуулалт цуцлагдсан. ",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} нь 0kb хэмжээтэй эсвэл ижил нэр бүхий хавтас байгаа тул байршуулах боломжгүй",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "хангалттай зай үлдээгүй байна, та {size1} хэмжээтэй файл оруулж байна гэхдээ зөвхөн {size2} ийн хэмжээний сул зай үлдсэн байна",
    "Target folder \"{dir}\" does not exist any more" : "{dir} гэх байршуулах хавтас олдсонгүй",
    "Not enough free space" : "Сул зай хүрэлцэхгүй байна",
    "Uploading …" : "Байршуулж байна...",
    "Uploading that item is not supported" : "Энэ төрлийн файл байршуулах боломжгүй",
    "Target folder does not exist any more" : "Байршуулах хавтас олдсонгүй",
    "Error when assembling chunks, status code {status}" : "Бүрдэл хэсгүүдийг нэгтгэхэд алдаа гарлаа. Төлвийн код {status}",
    "Actions" : "Үйл ажиллагаа",
    "Rename" : "Нэр өөрчлөх",
    "Copy" : "Хуулах",
    "Disconnect storage" : "Хадгалах төхөөрөмж салгах",
    "Unshare" : "Түгээлтийг зогсоох",
    "Files" : "Файлууд",
    "Details" : "Дэлгэрэнгүй",
    "Select" : "Сонгох",
    "Pending" : "Хүлээгдэж байгаа",
    "Unable to determine date" : "Огноог тодорхойлох боломжгүй",
    "This operation is forbidden" : "Энэ үйлдэл хориотой",
    "This directory is unavailable, please check the logs or contact the administrator" : "Энэ хавтас байхгүй байна, үйлдлийн лог шалгах эсвэл админ хэрэглэгчтэй холбогдоно уу.",
    "Could not move \"{file}\", target exists" : "\"{file}\" -г зөөж чадсангүй, алдаа: target exists ",
    "Could not move \"{file}\"" : "Файлыг зөөж чадсангүй: \"{file}\"",
    "Could not copy \"{file}\", target exists" : "\"{file}\"-г зөөж чадсангүй, файлын нэр давхцаж байна",
    "Could not copy \"{file}\"" : "\"{file}\"-г зөөж чадсангүй",
    "Copied {origin} inside {destination}" : "Хуулбар хийгдэж {destination} дотор {origin} байршлаа",
    "{newName} already exists" : "{newName} нэр давцаж байна",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" файлын нэрийг солих боломжгүй, энэ файл устгагдсан байна",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{dir}\" хавтаст \"{targetName}\" гэх нэрийг ашигласан байна. Өөр нэр сонгоно уу.",
    "Could not rename \"{fileName}\"" : "Файлын нэрийг сольж чадсангүй: \"{fileName}\"",
    "Could not create file \"{file}\"" : "\"{file}\" файлыг үүсгэж чадсангүй",
    "Could not create file \"{file}\" because it already exists" : "Ийм нэртэй файл байгаа учир \"{file}\"-г үүсгэж чадахгүй",
    "Could not create folder \"{dir}\" because it already exists" : " \"{dir}\" хавтасыг үүсгэх боломжгүй, нэр нь давцаж байна",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" файлыг устгахад алдаа гарлаа.",
    "No search results in other folders for {tag}{filter}{endtag}" : "{tag}{filter}{endtag} хайлтад тохирох үр дүн бусад хавтасаас олсонгүй",
    "Name" : "Нэр",
    "Size" : "Хэмжээ",
    "Modified" : "Өөрчлөгдсөн",
    "_%n folder_::_%n folders_" : ["хавтас","хавтсууд"],
    "_%n file_::_%n files_" : ["файл","файлууд"],
    "{dirs} and {files}" : "{dirs} болон {files}",
    "_including %n hidden_::_including %n hidden_" : ["нуугдсан %n хамруулан","нуугдсан %n хамруулан"],
    "You don’t have permission to upload or create files here" : "Та энэ байршилд файл үүсгэх эсвэл байршуулах эрхгүй байна.",
    "_Uploading %n file_::_Uploading %n files_" : ["Файлыг байршуулж байна","%n файлыг байршуулж байна"],
    "New" : "Шинэ",
    "{used} of {quota} used" : "{quota} оноосноос {used} хэрэглэсэн",
    "{used} used" : "{user} хэрэглэсэн",
    "\"{name}\" is an invalid file name." : "\"{name}\" нь хүчин төгөлдөр бус файлын нэр",
    "File name cannot be empty." : "Файлын нэр хоосон байж болохгүй.",
    "\"/\" is not allowed inside a file name." : "файлын нэр \"/\" агуулж болохгүй",
    "View in folder" : "Хавтасыг нээх",
    "Copied!" : "Хуулсан!",
    "Path" : "Зам",
    "Favorite" : "Дуртай",
    "New folder" : "Шинэ хавтас",
    "Upload file" : "Файл байршуулах",
    "An error occurred while trying to update the tags" : "Tag шинэчлэхэд алдаа гарлаа",
    "Added to favorites" : "Дуртай файлаар сонгов",
    "You added {file} to your favorites" : "{file} дуртай файлаар сонгов",
    "You removed {file} from your favorites" : "Та дуртай файлын жагсаалтаас  {file}-г хасав",
    "File changes" : "Файлын өөрчлөлтүүд",
    "Created by {user}" : "{user} үүсгэсэн",
    "Changed by {user}" : "{user} өөрчилсөн",
    "Deleted by {user}" : "{user} устгасан",
    "Restored by {user}" : "{user} сэргээсэн",
    "Renamed by {user}" : "{user} нэр солисон",
    "Moved by {user}" : "{user} зөөсөн",
    "\"remote user\"" : "алсын хэрэглэгч",
    "You created {file}" : "{file} файлыг та үүсгэв",
    "{user} created {file}" : "{user} {file}-г үүсгэв",
    "{file} was created in a public folder" : "{file} нийтийн хавтсанд үүсгэгдсэн",
    "You changed {file}" : "Та {file} файлыг өөрчлөв",
    "{user} changed {file}" : "{user} хэрэглэгч {file}-г өөрчлөв",
    "You deleted {file}" : "Та {file} файлыг устгав",
    "{user} deleted {file}" : "{user} хэрэглэгч {file} файлыг устгав",
    "You restored {file}" : "Та {file} файлыг сэргээв",
    "{user} restored {file}" : "{user} хэрэглэгч {file} файлыг сэргээв",
    "You renamed {oldfile} to {newfile}" : "Та {oldfile} файлын нэрйиг {newfile} болгож өөрчлөв",
    "{user} renamed {oldfile} to {newfile}" : "{user} хэрэглэгч {oldfile} файлын нэрийг {newfile} болгож өөрчлөв",
    "You moved {oldfile} to {newfile}" : "Та {oldfile} файлыг {newfile} болгож зөөв",
    "{user} moved {oldfile} to {newfile}" : "{user} хэрэглэгч {oldfile} файлыг {newfile} болгож зөөв",
    "Settings" : "Тохиргоо",
    "Show hidden files" : "Нууцлагдсан файлыг харах",
    "No files in here" : "энэд файл байхгүй байна",
    "No entries found in this folder" : "энэ хавтсан олдсон ч ямарч мэдээлэл олдохгүй байна",
    "Select all" : "бүгдийг сонгох",
    "Upload too large" : "маш том байршуулалт",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Таны байршуулах гэж оролдсон файлууд нь энэ сервер дээр файл байршуулах дээд хэмжээнээс хэтэрч.",
    "Tags" : "Тэгүүд",
    "Deleted files" : "Устгасан файлууд",
    "Shared with others" : "Бусдад түгээсэн",
    "Shared by link" : "Холбоосоор түгээсэн",
    "Text file" : "текст файл",
    "New text file.txt" : "шинэ текст file.txt",
    "Target folder" : "Заагч хавтас",
    "File handling" : "файлтай харьцах",
    "Maximum upload size" : "хамгийн их байршуулах хэмжээ",
    "max. possible: " : "боломжтой хамгийн их хэмжээ",
    "Save" : "хадгалах"
},
"nplurals=2; plural=(n != 1);");
